# libpythonpro
Modulo para exemplificar construção de projetos Python no Curso Pytools

Nesse curso é ensinado a como contribuir com projetos de codigo aberto.

[![Build Status](https://travis-ci.com/joaonetoeng/libpythonpro.svg?branch=master)](https://travis-ci.com/joaonetoeng/libpythonpro)

[![Updates](https://pyup.io/repos/github/joaonetoeng/libpythonpro/shield.svg)](https://pyup.io/repos/github/joaonetoeng/libpythonpro/)

[![Python 3](https://pyup.io/repos/github/joaonetoeng/libpythonpro/python-3-shield.svg)](https://pyup.io/repos/github/joaonetoeng/libpythonpro/)
